package mysql

import (
	"context"
	"fmt"
	"pji_desktop_http/biz/dal/query"
	"pji_desktop_http/biz/model"
)

func AddSimulationTestRecords(ctx context.Context, records []*model.SimulationTestRecord) error {
	r := query.SimulationTestRecord
	err := r.WithContext(ctx).Create(records...)
	return err
}

//func QuerySimulationTestRecords(ctx context.Context, sceneId string, testTime string) ([]*model.SimulationTestRecord, error) {
//	r := query.SimulationTestRecord
//	records, err := r.WithContext(ctx).Where(r.SceneID.Eq(sceneId), r.TestTime.Eq(testTime)).Order(r.Round.Asc()).Find()
//	if err != nil {
//		fmt.Println("Query simulation records failed:", err.Error())
//		return nil, err
//	}
//	fmt.Print("Query simulation records successfully:", records)
//	return records, err
//}

func QuerySimulationTestRecords(ctx context.Context, record *model.SimulationTestRecord, pageFlag bool, page, pageSize int) ([]*model.SimulationTestRecord, int64, error) {
	r := query.SimulationTestRecord
	q := r.WithContext(ctx)
	var records []*model.SimulationTestRecord
	var count int64
	var err error
	if record.DeviceType != "" {
		q = q.Where(r.DeviceType.Eq(record.DeviceType))
	}
	if record.AlgoEvaluationLevel != "" {
		fmt.Println("AlgoEvaluationLevel", record.AlgoEvaluationLevel)
		q = q.Where(r.AlgoEvaluationLevel.Eq(record.AlgoEvaluationLevel))
	}
	if record.DeviceName != "" {
		q = q.Where(r.DeviceName.Like("%" + record.DeviceName + "%"))
	}
	if record.AlgoImageName != "" {
		q = q.Where(r.AlgoImageName.Like("%" + record.AlgoImageName + "%"))
	}
	if record.TestTime != "" {
		q = q.Where(r.TestTime.Eq(record.TestTime))
	}
	if record.SceneID != "" {
		q = q.Where(r.SceneID.Eq(record.SceneID))
	}
	if pageFlag {
		offset := (page - 1) * pageSize
		records, count, err = q.Order(r.TestTime.Desc(), r.Round.Asc()).FindByPage(offset, pageSize)
	} else {
		records, err = q.Order(r.TestTime.Desc(), r.Round.Asc()).Find()
	}

	if err != nil {
		fmt.Println("Query simulation records failed:", err.Error())
		return nil, 0, err
	}

	fmt.Println("Query simulation records successfully:", len(records))
	return records, count, err
}
